@@ -5,11 +5,10 @@ package Data::Scan::Impl::Printer;
 
 # ABSTRACT: Data::Scan printer implementation
 
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 # AUTHORITY
 
-use Data::Dumper;
 use IO::Interactive::Tiny;
 use Moo;
 use Perl::OSType qw/is_os_type/;
@@ -96,7 +95,7 @@ has _seen                   => (is => 'rw', isa => HashRef[PositiveOrZeroInt],
 #
 # Required methods
 #
-sub start  {
+sub dsstart  {
   my ($self) = @_;
   $self->_clear_lines;
   $self->_clear_currentLevel;
@@ -105,14 +104,14 @@ sub start  {
   $self->_clear_seen;
 }
 
-sub end { !!1 }
+sub dsend { !!1 }
 
-sub output {
+sub dsoutput {
   my ($self) = @_;
   return join($self->newline, @{$self->_lines})
 }
 
-sub sopen {
+sub dsopen {
   my ($self, $item) = @_;
 
   my $reftype = reftype $item;
@@ -126,7 +125,7 @@ sub sopen {
   return
 }
 
-sub sclose {
+sub dsclose {
   my ($self, $item) = @_;
 
   $self->_popLevel;
@@ -138,7 +137,7 @@ sub sclose {
   return
 }
 
-sub sread {
+sub dsread {
   my ($self, $item) = @_;
 
   my $refaddr = refaddr($item);
@@ -334,7 +333,7 @@ Data::Scan::Impl::Printer - Data::Scan printer implementation
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 AUTHOR
 
