@@ -6,16 +6,15 @@ use Moo::Role;
 
 # ABSTRACT: Data::Scan consumer role
 
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 # AUTHORITY
 
-requires 'start';
-requires 'sopen';
-requires 'sread';
-requires 'sclose';
-requires 'end';
-requires 'output';
+requires 'dsstart';
+requires 'dsopen';
+requires 'dsread';
+requires 'dsclose';
+requires 'dsend';
 
 1;
 
@@ -31,7 +30,7 @@ Data::Scan::Role::Consumer - Data::Scan consumer role
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 AUTHOR
 
